@@ -2,10 +2,6 @@
 #include <sys/ioctl.h>
 #include <sys/types.h>
 
-#if defined(__linux__)
-#include <sys/sysmacros.h>
-#endif
-
 #include "drm.h"
 
 // From libdrm
@@ -24,16 +20,12 @@ int drm_drop_master(int fd) {
 	return ioctl(fd, DRM_IOCTL_DROP_MASTER, 0);
 }
 
-#if defined(__linux__)
+#if defined(__linux__) || defined(__NetBSD__)
 int path_is_drm(const char *path) {
 	static const char prefix[] = "/dev/dri/";
 	static const int prefixlen = STRLEN(prefix);
 	return strncmp(prefix, path, prefixlen) == 0;
 }
-
-int dev_is_drm(dev_t device) {
-	return major(device) == 226;
-}
 #elif defined(__FreeBSD__)
 int path_is_drm(const char *path) {
 	static const char prefix[] = "/dev/drm/";
